# Helperize

This is an experiment to build an AI helper.

## Install

```shell
pip install helperize
```

## Usage

```shell
# See all available commands
poetry run helperize -h
```

## Development

For development, we use `poetry` to manage dependencies. To install `poetry`, follow the
instructions [here](https://python-poetry.org/docs/#installation). Then you can install the project:

```shell
make install
```
